# uassist


[![image](https://img.shields.io/pypi/v/uassist.svg)](https://pypi.python.org/pypi/uassist)


**UASsist: Assistant for Unmanned Aircraft System photogrammetry for surveying and mapping applications. **


-   Free software: GNU General Public License v3
-   Documentation: https://nathanmckinney.github.io/uassist
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
